# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.21
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_resources_response import ListResourcesResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListResourcesResponse(unittest.TestCase):
    """ListResourcesResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListResourcesResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_resources_response.ListResourcesResponse()  # noqa: E501
        if include_optional :
            return ListResourcesResponse(
                resources = [
                    agilicus_api.models.resource.Resource(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.resource_spec.ResourceSpec(
                            name = 'my-application', 
                            resource_type = 'fileshare', 
                            org_id = 'S38d8dk3Xirt69', 
                            name_slug = 'a', 
                            not_assignable_perm = True, ), 
                        status = agilicus_api.models.resource_status.ResourceStatus(
                            resource_stats = agilicus_api.models.resource_stats.ResourceStats(
                                resource_id = 'S38d8dk3Xirt69', 
                                overall_status = '0', 
                                last_warning_message = '0', 
                                session_stats = agilicus_api.models.resource_session_stats.ResourceSessionStats(
                                    total = 56, 
                                    allowed = 56, 
                                    denied = 56, ), ), ), )
                    ], 
                limit = 56, 
                page_at_id = 'sd0X4asd3as'
            )
        else :
            return ListResourcesResponse(
                resources = [
                    agilicus_api.models.resource.Resource(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.resource_spec.ResourceSpec(
                            name = 'my-application', 
                            resource_type = 'fileshare', 
                            org_id = 'S38d8dk3Xirt69', 
                            name_slug = 'a', 
                            not_assignable_perm = True, ), 
                        status = agilicus_api.models.resource_status.ResourceStatus(
                            resource_stats = agilicus_api.models.resource_stats.ResourceStats(
                                resource_id = 'S38d8dk3Xirt69', 
                                overall_status = '0', 
                                last_warning_message = '0', 
                                session_stats = agilicus_api.models.resource_session_stats.ResourceSessionStats(
                                    total = 56, 
                                    allowed = 56, 
                                    denied = 56, ), ), ), )
                    ],
                limit = 56,
        )

    def testListResourcesResponse(self):
        """Test ListResourcesResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.21
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.allow_rule_compiled import AllowRuleCompiled  # noqa: E501
from agilicus_api.rest import ApiException

class TestAllowRuleCompiled(unittest.TestCase):
    """AllowRuleCompiled unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AllowRuleCompiled
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.allow_rule_compiled.AllowRuleCompiled()  # noqa: E501
        if include_optional :
            return AllowRuleCompiled(
                paths = [
                    '/.*'
                    ], 
                methods = ["get"], 
                any_auth_user = True
            )
        else :
            return AllowRuleCompiled(
        )

    def testAllowRuleCompiled(self):
        """Test AllowRuleCompiled"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.21
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.resource_stats import ResourceStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestResourceStats(unittest.TestCase):
    """ResourceStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ResourceStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.resource_stats.ResourceStats()  # noqa: E501
        if include_optional :
            return ResourceStats(
                resource_id = 'S38d8dk3Xirt69', 
                metadata = agilicus_api.models.resource_stats_metadata.ResourceStatsMetadata(
                    creation_time = '2020-07-07T15:40:46.010Z', 
                    collection_time = '2020-07-07T15:49:51.230Z', 
                    receipt_time = '2020-07-07T15:49:51.530Z', ), 
                overall_status = '0', 
                last_warning_message = '0', 
                session_stats = agilicus_api.models.resource_session_stats.ResourceSessionStats(
                    total = 56, 
                    allowed = 56, 
                    denied = 56, )
            )
        else :
            return ResourceStats(
        )

    def testResourceStats(self):
        """Test ResourceStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.21
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class UpstreamGroupReconcileResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'groups_added_to': 'list[GroupReconcileRecord]',
        'groups_removed_from': 'list[GroupReconcileRecord]',
        'resulting_groups': 'list[GroupReconcileRecord]'
    }

    attribute_map = {
        'groups_added_to': 'groups_added_to',
        'groups_removed_from': 'groups_removed_from',
        'resulting_groups': 'resulting_groups'
    }

    def __init__(self, groups_added_to=None, groups_removed_from=None, resulting_groups=None, local_vars_configuration=None):  # noqa: E501
        """UpstreamGroupReconcileResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._groups_added_to = None
        self._groups_removed_from = None
        self._resulting_groups = None
        self.discriminator = None

        if groups_added_to is not None:
            self.groups_added_to = groups_added_to
        if groups_removed_from is not None:
            self.groups_removed_from = groups_removed_from
        if resulting_groups is not None:
            self.resulting_groups = resulting_groups

    @property
    def groups_added_to(self):
        """Gets the groups_added_to of this UpstreamGroupReconcileResponse.  # noqa: E501

        The list of groups the user was added to due to a reconcile.  # noqa: E501

        :return: The groups_added_to of this UpstreamGroupReconcileResponse.  # noqa: E501
        :rtype: list[GroupReconcileRecord]
        """
        return self._groups_added_to

    @groups_added_to.setter
    def groups_added_to(self, groups_added_to):
        """Sets the groups_added_to of this UpstreamGroupReconcileResponse.

        The list of groups the user was added to due to a reconcile.  # noqa: E501

        :param groups_added_to: The groups_added_to of this UpstreamGroupReconcileResponse.  # noqa: E501
        :type: list[GroupReconcileRecord]
        """

        self._groups_added_to = groups_added_to

    @property
    def groups_removed_from(self):
        """Gets the groups_removed_from of this UpstreamGroupReconcileResponse.  # noqa: E501

        The list of groups the user was removed from due to a reconcile.  # noqa: E501

        :return: The groups_removed_from of this UpstreamGroupReconcileResponse.  # noqa: E501
        :rtype: list[GroupReconcileRecord]
        """
        return self._groups_removed_from

    @groups_removed_from.setter
    def groups_removed_from(self, groups_removed_from):
        """Sets the groups_removed_from of this UpstreamGroupReconcileResponse.

        The list of groups the user was removed from due to a reconcile.  # noqa: E501

        :param groups_removed_from: The groups_removed_from of this UpstreamGroupReconcileResponse.  # noqa: E501
        :type: list[GroupReconcileRecord]
        """

        self._groups_removed_from = groups_removed_from

    @property
    def resulting_groups(self):
        """Gets the resulting_groups of this UpstreamGroupReconcileResponse.  # noqa: E501

        The list of groups the user is a member of as a result of reconciliation.  # noqa: E501

        :return: The resulting_groups of this UpstreamGroupReconcileResponse.  # noqa: E501
        :rtype: list[GroupReconcileRecord]
        """
        return self._resulting_groups

    @resulting_groups.setter
    def resulting_groups(self, resulting_groups):
        """Sets the resulting_groups of this UpstreamGroupReconcileResponse.

        The list of groups the user is a member of as a result of reconciliation.  # noqa: E501

        :param resulting_groups: The resulting_groups of this UpstreamGroupReconcileResponse.  # noqa: E501
        :type: list[GroupReconcileRecord]
        """

        self._resulting_groups = resulting_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpstreamGroupReconcileResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpstreamGroupReconcileResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.21
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.upstream_group_reconcile_response import UpstreamGroupReconcileResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestUpstreamGroupReconcileResponse(unittest.TestCase):
    """UpstreamGroupReconcileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpstreamGroupReconcileResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.upstream_group_reconcile_response.UpstreamGroupReconcileResponse()  # noqa: E501
        if include_optional :
            return UpstreamGroupReconcileResponse(
                groups_added_to = [
                    agilicus_api.models.group_reconcile_record.GroupReconcileRecord(
                        name = 'My Timesheet Users', 
                        org_id = 'IAsl3dl40aSsfLKiU76', 
                        group_id = 'IAsl3dl40aSsfLKiU76', )
                    ], 
                groups_removed_from = [
                    agilicus_api.models.group_reconcile_record.GroupReconcileRecord(
                        name = 'My Timesheet Users', 
                        org_id = 'IAsl3dl40aSsfLKiU76', 
                        group_id = 'IAsl3dl40aSsfLKiU76', )
                    ], 
                resulting_groups = [
                    agilicus_api.models.group_reconcile_record.GroupReconcileRecord(
                        name = 'My Timesheet Users', 
                        org_id = 'IAsl3dl40aSsfLKiU76', 
                        group_id = 'IAsl3dl40aSsfLKiU76', )
                    ]
            )
        else :
            return UpstreamGroupReconcileResponse(
        )

    def testUpstreamGroupReconcileResponse(self):
        """Test UpstreamGroupReconcileResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.21
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_sessions_response import ListSessionsResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListSessionsResponse(unittest.TestCase):
    """ListSessionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListSessionsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_sessions_response.ListSessionsResponse()  # noqa: E501
        if include_optional :
            return ListSessionsResponse(
                sessions = [
                    agilicus_api.models.session.Session(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.sessions_spec.SessionsSpec(
                            user_id = 'asdfghjklmn123', 
                            org_id = 'asdfghjklmn123', 
                            revoked = False, 
                            number_of_logins = 3, 
                            number_of_failed_multi_factor_challenges = 3, ), )
                    ], 
                limit = 56, 
                previous_created_time = '2015-07-07T15:49:51.230+02:00', 
                next_created_time = '2015-07-07T15:49:51.230+02:00', 
                previous_user_id = '123', 
                next_user_id = '123'
            )
        else :
            return ListSessionsResponse(
                sessions = [
                    agilicus_api.models.session.Session(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.sessions_spec.SessionsSpec(
                            user_id = 'asdfghjklmn123', 
                            org_id = 'asdfghjklmn123', 
                            revoked = False, 
                            number_of_logins = 3, 
                            number_of_failed_multi_factor_challenges = 3, ), )
                    ],
                limit = 56,
        )

    def testListSessionsResponse(self):
        """Test ListSessionsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
